#ifndef INCLUDED_GLOBAL_H_
#define INCLUDED_GLOBAL_H_

    /* 
        all global variables defined by lower level directories (classes),
        that must be used by upper level directories
    */

extern int yynerrs;         /* parser */

extern int yylineno;        /* scanner */
extern char *yytext;


#endif
